#########
 pybrary
#########

**Python Library**

========
Abstract
========

Python tools

=====
Usage
=====

.. code-block:: shell

    import pybrary


============
Installation
============

.. code-block:: shell 

    $ pip install pybrary
